@@ -8,7 +8,7 @@
 #
 import logging
 from dataclasses import dataclass
-from enum import StrEnum, unique
+from enum import Enum, unique
 
 from aiohttp import hdrs
 from http_tools import AbmServiceConnector
@@ -27,7 +27,7 @@ class TokenId(str):
 
 
 @unique
-class TokenType(StrEnum):
+class TokenType(str, Enum):
     access_token = "access_token"
     refresh_token = "refresh_token"
 
